@@ -373,10 +373,9 @@ fn test_calling_deflate_decompress_with_oversized_buf_returns_correct_size() {
 // compression
 
 #[test]
-fn test_compression_lvl_new_returns_err_for_zero() {
-    let ret = CompressionLvl::new(0).unwrap_err();
-
-    assert_eq!(ret, CompressionLvlError::InvalidValue);
+fn test_compression_lvl_new_returns_ok_for_0() {
+    // see issuse #21 - some use-cases require uncompressed blocks
+    CompressionLvl::new(0).unwrap();
 }
 
 #[test]
@@ -408,6 +407,13 @@ fn test_compressor_with_best_compression_lvl_calls_with_no_panics() {
     Compressor::new(CompressionLvl::best());
 }
 
+#[test]
+fn test_compression_iter_starts_at_compression_lvl_zero() {
+    let val = CompressionLvl::iter().next().unwrap();
+    assert_eq!(val, CompressionLvl::fastest());
+    assert_eq!(val, CompressionLvl::new(0).unwrap());
+}
+
 #[test]
 fn test_compressor_with_compression_lvl_can_be_called_with_all_lvls_with_no_panics() {
     for lvl in CompressionLvl::iter() {
